==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grop important:</b> s’aconselha tot plen de seleccionar un mot clau dins aqueu grop.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'lu administrators dau sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'lu redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'lu vesitaires dau sit public quora mandan un messatge dins un forum.',

	// I
	'icone_creation_groupe_mots' => 'Crear un novèu grop de mots',
	'icone_creation_mots_cles' => 'Crear un mot clau nòu',
	'icone_modif_groupe_mots' => 'Modificar aqueu grop de mots',
	'icone_mots_cles' => 'Mots clau',
	'icone_supprimer_groupe_mots' => 'Suprimir aqueu document',
	'icone_voir_tous_mots_cles' => 'Veire toi lu mots clau ',
	'info_articles_lies_mot' => 'Lu articles ligats a aqueu mot clau',
	'info_changer_nom_groupe' => 'Cambiar lo nom d’aqueu grop:',
	'info_creation_mots_cles' => 'Creatz e configuratz aicí lu mots clau dau sit',
	'info_dans_groupe' => 'Dins lo grop:',
	'info_delet_mots_cles' => 'Avètz demandat de suprimir lo mot clau
 <b>@titre_mot@</b> (@type_mot@). Aqueu mot clau es ligat a
 <b>@texte_lie@</b>. Devètz confirmar aquela decision:', # MODIF
	'info_groupe_important' => 'Grop important',
	'info_mots_cles' => 'Lu mots clau',
	'info_mots_cles_association' => 'Lu mots clau d’aqueu grop si pòdon associar:',
	'info_oui_suppression_mot_cle' => 'Vòli suprimir aqueu mot clau definitivament.',
	'info_question_mots_cles' => 'Desiratz d’utilizar lu mots clau sus lo vòstre sit?',
	'info_qui_attribue_mot_cle' => 'Lu mots d’aqueu grop pòdon èstre atribuits per:',
	'info_retirer_mot' => 'Quitar aqueu mot',
	'info_retirer_mots' => 'Quitar toi lu mots ',
	'info_rubriques_liees_mot' => 'Li rubricas ligadas a aqueu mot clau',
	'info_selection_un_seul_mot_cle' => 'Si pòu seleccionar basta <b>un mot clau</b> a l’encòup dins aqueu grop.', # MODIF
	'info_supprimer_mot' => 'suprimir aqueu mot',
	'info_titre_mot_cle' => 'Nom ò títol dau mot clau',
	'info_un_mot' => 'Basta un mot a l’encòup',
	'item_ajout_mots_cles' => 'Autorizar que s’aponda de mots clau ai forums',
	'item_non_ajout_mots_cles' => 'Proïbir l’utilizacion dei mots clau dins lu forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'Non utilizar la configuracion avançada dei grops de mots clau',
	'item_non_utiliser_mots_cles' => 'Non utilizar lu mots clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuracion avançada dei grops de mots clau',
	'item_utiliser_mots_cles' => 'Utilizar lu mots clau',

	// L
	'logo_mot_cle' => 'LÒGO DAU MOT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Desiratz, vos, d’activar la configuracion avançada dei mots clau,
 en indicant per exemple que si pòu seleccionar un mot unenc
 per grop, qu’un grop es important...?', # MODIF
	'texte_mots_cles' => 'Gaug ai mots clau podètz crear de ligams tematics entre vòstres articles
  qué que sia la sieu plaça dins li rubricas. Aquò vos permete
  d’enriquir la navigacion dau vòstre sit, e finda d’utilizar aqueli proprietats 
  per personalizar la presentacion dei articles dins li esqueletas. ',
	'texte_mots_cles_dans_forum' => 'Desiratz, vos, de permetre l’utilizacion dei mots clau, seleccionables per lu vesitaires, dins lu forums dau sit public? (Atencion: es pron complèxe d’utilizar aquela opcion correctament.)',
	'texte_nouveau_mot' => 'Mot nòu',
	'titre_config_groupe_mots_cles' => 'Configuracion dei grops de mots clau',
	'titre_gauche_mots_edit' => 'MOT NÚMERO:',
	'titre_mots_cles_dans_forum' => 'Mots clau dins lu forums dau sit public',
	'titre_mots_tous' => 'Lu mots clau',
	'titre_nouveau_groupe' => 'Grop novèu',
	'titre_page_mots_tous' => 'Lu mots clau'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grop important:</b> s’aconselha tot plen de seleccionar un mot clau dins aqueu grop.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'lu administrators dau sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'lu redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'lu vesitaires dau sit public quora mandan un messatge dins un forum.',

	// I
	'icone_creation_groupe_mots' => 'Crear un novèu grop de mots',
	'icone_creation_mots_cles' => 'Crear un mot clau nòu',
	'icone_modif_groupe_mots' => 'Modificar aqueu grop de mots',
	'icone_mots_cles' => 'Mots clau',
	'icone_supprimer_groupe_mots' => 'Suprimir aqueu document',
	'icone_voir_tous_mots_cles' => 'Veire toi lu mots clau ',
	'info_articles_lies_mot' => 'Lu articles ligats a aqueu mot clau',
	'info_changer_nom_groupe' => 'Cambiar lo nom d’aqueu grop:',
	'info_creation_mots_cles' => 'Creatz e configuratz aicí lu mots clau dau sit',
	'info_dans_groupe' => 'Dins lo grop:',
	'info_delet_mots_cles' => 'Avètz demandat de suprimir lo mot clau
 <b>@titre_mot@</b> (@type_mot@). Aqueu mot clau es ligat a
 <b>@texte_lie@</b>. Devètz confirmar aquela decision:', # MODIF
	'info_groupe_important' => 'Grop important',
	'info_mots_cles' => 'Lu mots clau',
	'info_mots_cles_association' => 'Lu mots clau d’aqueu grop si pòdon associar:',
	'info_oui_suppression_mot_cle' => 'Vòli suprimir aqueu mot clau definitivament.',
	'info_question_mots_cles' => 'Desiratz d’utilizar lu mots clau sus lo vòstre sit?',
	'info_qui_attribue_mot_cle' => 'Lu mots d’aqueu grop pòdon èstre atribuits per:',
	'info_retirer_mot' => 'Quitar aqueu mot',
	'info_retirer_mots' => 'Quitar toi lu mots ',
	'info_rubriques_liees_mot' => 'Li rubricas ligadas a aqueu mot clau',
	'info_selection_un_seul_mot_cle' => 'Si pòu seleccionar basta <b>un mot clau</b> a l’encòup dins aqueu grop.', # MODIF
	'info_supprimer_mot' => 'suprimir aqueu mot',
	'info_titre_mot_cle' => 'Nom ò títol dau mot clau',
	'info_un_mot' => 'Basta un mot a l’encòup',
	'item_ajout_mots_cles' => 'Autorizar que s’aponda de mots clau ai forums',
	'item_non_ajout_mots_cles' => 'Proïbir l’utilizacion dei mots clau dins lu forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'Non utilizar la configuracion avançada dei grops de mots clau',
	'item_non_utiliser_mots_cles' => 'Non utilizar lu mots clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuracion avançada dei grops de mots clau',
	'item_utiliser_mots_cles' => 'Utilizar lu mots clau',

	// L
	'logo_mot_cle' => 'LÒGO DAU MOT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Desiratz, vos, d’activar la configuracion avançada dei mots clau,
 en indicant per exemple que si pòu seleccionar un mot unenc
 per grop, qu’un grop es important...?', # MODIF
	'texte_mots_cles' => 'Gaug ai mots clau podètz crear de ligams tematics entre vòstres articles
  qué que sia la sieu plaça dins li rubricas. Aquò vos permete
  d’enriquir la navigacion dau vòstre sit, e finda d’utilizar aqueli proprietats 
  per personalizar la presentacion dei articles dins li esqueletas. ',
	'texte_mots_cles_dans_forum' => 'Desiratz, vos, de permetre l’utilizacion dei mots clau, seleccionables per lu vesitaires, dins lu forums dau sit public? (Atencion: es pron complèxe d’utilizar aquela opcion correctament.)',
	'texte_nouveau_mot' => 'Mot nòu',
	'titre_config_groupe_mots_cles' => 'Configuracion dei grops de mots clau',
	'titre_gauche_mots_edit' => 'MOT NÚMERO:',
	'titre_mots_cles_dans_forum' => 'Mots clau dins lu forums dau sit public',
	'titre_mots_tous' => 'Lu mots clau',
	'titre_nouveau_groupe' => 'Grop novèu',
	'titre_page_mots_tous' => 'Lu mots clau',
];
